@@ -16,5 +16,5 @@
 
 from .flowpy import (flow_to_rgb, make_colorwheel, calibration_pattern,
                      attach_arrows, attach_coord, attach_calibration_pattern,
-                     get_flow_max_radius, backward_warp, forward_warp)
+                     get_flow_max_radius, backward_warp, forward_warp, flowshow)
 from .flow_io import flow_read, flow_write
